@@ -8,8 +8,8 @@ Several mixins for making Django's generic class-based views more useful.
 :license: BSD 3-clause. See LICENSE for more details
 """
 
-__title__ = 'braces'
-__version__ = '1.14.0'
-__author__ = 'Kenneth Love and Chris Jones'
-__license__ = 'BSD 3-clause'
-__copyright__ = 'Copyright 2013 Kenneth Love and Chris Jones'
+__title__ = "braces"
+__version__ = "1.15.0"
+__author__ = "Kenneth Love and Chris Jones"
+__license__ = "BSD 3-clause"
+__copyright__ = "Copyright 2013 Kenneth Love and Chris Jones"
