@@ -1,37 +1,36 @@
-from __future__ import unicode_literals
-
 import json
 from django.core import serializers
 from django.core.exceptions import ImproperlyConfigured
 from django.core.serializers.json import DjangoJSONEncoder
 from django.http import HttpResponse, HttpResponseBadRequest
 
-import six
-
 
 class JSONResponseMixin(object):
     """
     A mixin that allows you to easily serialize simple data such as a dict or
     Django models.
     """
+
     content_type = None
     json_dumps_kwargs = None
     json_encoder_class = DjangoJSONEncoder
 
     def get_content_type(self):
-        if (self.content_type is not None and
-            not isinstance(self.content_type,
-                           (six.string_types, six.text_type))):
+        if self.content_type is not None and not isinstance(
+            self.content_type, str
+        ):
             raise ImproperlyConfigured(
-                '{0} is missing a content type. Define {0}.content_type, '
-                'or override {0}.get_content_type().'.format(
-                    self.__class__.__name__))
+                "{0} is missing a content type. Define {0}.content_type, "
+                "or override {0}.get_content_type().".format(
+                    self.__class__.__name__
+                )
+            )
         return self.content_type or "application/json"
 
     def get_json_dumps_kwargs(self):
         if self.json_dumps_kwargs is None:
             self.json_dumps_kwargs = {}
-        self.json_dumps_kwargs.setdefault('ensure_ascii', False)
+        self.json_dumps_kwargs.setdefault("ensure_ascii", False)
         return self.json_dumps_kwargs
 
     def render_json_response(self, context_dict, status=200):
@@ -42,10 +41,11 @@ class JSONResponseMixin(object):
         json_context = json.dumps(
             context_dict,
             cls=self.json_encoder_class,
-            **self.get_json_dumps_kwargs()).encode('utf-8')
-        return HttpResponse(json_context,
-                            content_type=self.get_content_type(),
-                            status=status)
+            **self.get_json_dumps_kwargs()
+        ).encode("utf-8")
+        return HttpResponse(
+            json_context, content_type=self.get_content_type(), status=status
+        )
 
     def render_json_object_response(self, objects, **kwargs):
         """
@@ -62,19 +62,24 @@ class AjaxResponseMixin(object):
     to the normal get, post, and put methods, you can use get_ajax, post_ajax,
     and put_ajax.
     """
+
     def dispatch(self, request, *args, **kwargs):
         request_method = request.method.lower()
 
         if request.is_ajax() and request_method in self.http_method_names:
-            handler = getattr(self, "{0}_ajax".format(request_method),
-                              self.http_method_not_allowed)
+            handler = getattr(
+                self,
+                "{0}_ajax".format(request_method),
+                self.http_method_not_allowed,
+            )
             self.request = request
             self.args = args
             self.kwargs = kwargs
             return handler(request, *args, **kwargs)
 
         return super(AjaxResponseMixin, self).dispatch(
-            request, *args, **kwargs)
+            request, *args, **kwargs
+        )
 
     def get_ajax(self, request, *args, **kwargs):
         return self.get(request, *args, **kwargs)
@@ -108,6 +113,7 @@ class JsonRequestResponseMixin(JSONResponseMixin):
                 return self.render_json_response(
                     {'message': 'Thanks!'})
     """
+
     require_json = False
     error_response_dict = {"errors": ["Improperly formatted request"]}
 
@@ -118,13 +124,14 @@ class JsonRequestResponseMixin(JSONResponseMixin):
             error_dict,
             cls=self.json_encoder_class,
             **self.get_json_dumps_kwargs()
-        ).encode('utf-8')
+        ).encode("utf-8")
         return HttpResponseBadRequest(
-            json_context, content_type=self.get_content_type())
+            json_context, content_type=self.get_content_type()
+        )
 
     def get_request_json(self):
         try:
-            return json.loads(self.request.body.decode('utf-8'))
+            return json.loads(self.request.body.decode("utf-8"))
         except ValueError:
             return None
 
@@ -134,14 +141,17 @@ class JsonRequestResponseMixin(JSONResponseMixin):
         self.kwargs = kwargs
 
         self.request_json = self.get_request_json()
-        if all([
-            request.method != 'OPTIONS',
-            self.require_json,
-            self.request_json is None
-        ]):
+        if all(
+            [
+                request.method != "OPTIONS",
+                self.require_json,
+                self.request_json is None,
+            ]
+        ):
             return self.render_bad_request_response()
         return super(JsonRequestResponseMixin, self).dispatch(
-            request, *args, **kwargs)
+            request, *args, **kwargs
+        )
 
 
 class JSONRequestResponseMixin(JsonRequestResponseMixin):
