@@ -4,5 +4,5 @@ from tests import settings as test_settings
 
 
 def pytest_configure():
-    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'tests.settings')
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tests.settings")
     settings.configure(default_settings=test_settings)
