@@ -1,5 +1,3 @@
-from __future__ import absolute_import
-
 from django import forms
 
 from braces.forms import UserKwargModelFormMixin
@@ -14,4 +12,4 @@ class FormWithUserKwarg(UserKwargModelFormMixin, forms.Form):
 class ArticleForm(forms.ModelForm):
     class Meta:
         model = Article
-        fields = ['author', 'title', 'body', 'slug']
+        fields = ["author", "title", "body", "slug"]
