@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import datetime
 
 import pytest
@@ -9,22 +6,27 @@ from django import test
 from django.test.utils import override_settings
 from django.core.exceptions import ImproperlyConfigured, PermissionDenied
 from django.http import Http404, HttpResponse
+from django.utils.encoding import force_str
 from django.utils.timezone import make_aware, get_current_timezone
 
-try:
-    from django.urls import reverse_lazy
-except ImportError:
-    from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse_lazy
 
-from .compat import force_string
 from .factories import GroupFactory, UserFactory
 from .helpers import TestViewHelper
-from .views import (PermissionRequiredView, MultiplePermissionsRequiredView,
-                    SuperuserRequiredView, StaffuserRequiredView,
-                    LoginRequiredView, GroupRequiredView, UserPassesTestView,
-                    UserPassesTestNotImplementedView, AnonymousRequiredView,
-                    SSLRequiredView, RecentLoginRequiredView,
-                    UserPassesTestLoginRequiredView)
+from .views import (
+    PermissionRequiredView,
+    MultiplePermissionsRequiredView,
+    SuperuserRequiredView,
+    StaffuserRequiredView,
+    LoginRequiredView,
+    GroupRequiredView,
+    UserPassesTestView,
+    UserPassesTestNotImplementedView,
+    AnonymousRequiredView,
+    SSLRequiredView,
+    RecentLoginRequiredView,
+    UserPassesTestLoginRequiredView,
+)
 
 
 @pytest.mark.django_db
@@ -32,6 +34,7 @@ class _TestAccessBasicsMixin(TestViewHelper):
     """
     A set of basic tests for access mixins.
     """
+
     view_url = None
 
     def build_authorized_user(self):
@@ -51,10 +54,10 @@ class _TestAccessBasicsMixin(TestViewHelper):
         If user is authorized then view should return normal response.
         """
         user = self.build_authorized_user()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
     def test_redirects_to_login(self):
         """
@@ -62,10 +65,11 @@ class _TestAccessBasicsMixin(TestViewHelper):
         to view this page.
         """
         user = self.build_unauthorized_user()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
-        self.assertRedirects(resp, '/accounts/login/?next={0}'.format(
-            self.view_url))
+        self.assertRedirects(
+            resp, "/accounts/login/?next={0}".format(self.view_url)
+        )
 
     def test_raise_permission_denied(self):
         """
@@ -116,7 +120,7 @@ class _TestAccessBasicsMixin(TestViewHelper):
 
         resp = self.dispatch_view(req, raise_exception=func)
         assert resp.status_code == 200
-        assert force_string(resp.content) == 'CUSTOM'
+        assert force_str(resp.content) == "CUSTOM"
 
     def test_raise_func_false(self):
         """
@@ -153,15 +157,16 @@ class _TestAccessBasicsMixin(TestViewHelper):
         """
         user = self.build_unauthorized_user()
         req = self.build_request(user=user, path=self.view_url)
-        resp = self.dispatch_view(req, login_url='/login/')
+        resp = self.dispatch_view(req, login_url="/login/")
         self.assertEqual(
-            '/login/?next={0}'.format(self.view_url),
-            resp['Location'])
+            "/login/?next={0}".format(self.view_url), resp["Location"]
+        )
 
         # Test with reverse_lazy
-        resp = self.dispatch_view(req, login_url=reverse_lazy('headline'))
-        self.assertEqual('/headline/?next={0}'.format(
-            self.view_url), resp['Location'])
+        resp = self.dispatch_view(req, login_url=reverse_lazy("headline"))
+        self.assertEqual(
+            "/headline/?next={0}".format(self.view_url), resp["Location"]
+        )
 
     def test_custom_redirect_field_name(self):
         """
@@ -169,9 +174,9 @@ class _TestAccessBasicsMixin(TestViewHelper):
         """
         user = self.build_unauthorized_user()
         req = self.build_request(user=user, path=self.view_url)
-        resp = self.dispatch_view(req, redirect_field_name='foo')
-        expected_url = '/accounts/login/?foo={0}'.format(self.view_url)
-        self.assertEqual(expected_url, resp['Location'])
+        resp = self.dispatch_view(req, redirect_field_name="foo")
+        expected_url = "/accounts/login/?foo={0}".format(self.view_url)
+        self.assertEqual(expected_url, resp["Location"])
 
     @override_settings(LOGIN_URL=None)
     def test_get_login_url_raises_exception(self):
@@ -181,7 +186,8 @@ class _TestAccessBasicsMixin(TestViewHelper):
         """
         with self.assertRaises(ImproperlyConfigured):
             self.dispatch_view(
-                self.build_request(path=self.view_url), login_url=None)
+                self.build_request(path=self.view_url), login_url=None
+            )
 
     def test_get_redirect_field_name_raises_exception(self):
         """
@@ -191,7 +197,8 @@ class _TestAccessBasicsMixin(TestViewHelper):
         with self.assertRaises(ImproperlyConfigured):
             self.dispatch_view(
                 self.build_request(path=self.view_url),
-                redirect_field_name=None)
+                redirect_field_name=None,
+            )
 
     @override_settings(LOGIN_URL="/auth/login/")
     def test_overridden_login_url(self):
@@ -200,26 +207,30 @@ class _TestAccessBasicsMixin(TestViewHelper):
         overridden dynamically.
         """
         user = self.build_unauthorized_user()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
-        self.assertRedirects(resp, '/auth/login/?next={0}'.format(
-            self.view_url))
+        self.assertRedirects(
+            resp, "/auth/login/?next={0}".format(self.view_url)
+        )
 
     def test_redirect_unauthenticated(self):
         resp = self.dispatch_view(
-                self.build_request(path=self.view_url),
-                raise_exception=True,
-                redirect_unauthenticated_users=True)
+            self.build_request(path=self.view_url),
+            raise_exception=True,
+            redirect_unauthenticated_users=True,
+        )
         assert resp.status_code == 302
-        assert resp['Location'] == '/accounts/login/?next={0}'.format(
-            self.view_url)
+        assert resp["Location"] == "/accounts/login/?next={0}".format(
+            self.view_url
+        )
 
     def test_redirect_unauthenticated_false(self):
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
                 self.build_request(path=self.view_url),
                 raise_exception=True,
-                redirect_unauthenticated_users=False)
+                redirect_unauthenticated_users=False,
+            )
 
 
 @pytest.mark.django_db
@@ -227,31 +238,35 @@ class TestLoginRequiredMixin(TestViewHelper, test.TestCase):
     """
     Tests for LoginRequiredMixin.
     """
+
     view_class = LoginRequiredView
-    view_url = '/login_required/'
+    view_url = "/login_required/"
 
     def test_anonymous(self):
         resp = self.client.get(self.view_url)
-        self.assertRedirects(resp, '/accounts/login/?next=/login_required/')
+        self.assertRedirects(resp, "/accounts/login/?next=/login_required/")
 
     def test_anonymous_raises_exception(self):
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
-                self.build_request(path=self.view_url), raise_exception=True)
+                self.build_request(path=self.view_url), raise_exception=True
+            )
 
     def test_authenticated(self):
         user = UserFactory()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
         assert resp.status_code == 200
-        assert force_string(resp.content) == 'OK'
+        assert force_str(resp.content) == "OK"
 
     def test_anonymous_redirects(self):
         resp = self.dispatch_view(
-            self.build_request(path=self.view_url), raise_exception=True,
-            redirect_unauthenticated_users=True)
+            self.build_request(path=self.view_url),
+            raise_exception=True,
+            redirect_unauthenticated_users=True,
+        )
         assert resp.status_code == 302
-        assert resp['Location'] == '/accounts/login/?next=/login_required/'
+        assert resp["Location"] == "/accounts/login/?next=/login_required/"
 
 
 @pytest.mark.django_db
@@ -259,22 +274,22 @@ class TestChainedLoginRequiredMixin(TestViewHelper, test.TestCase):
     """
     Tests for LoginRequiredMixin combined with another AccessMixin.
     """
+
     view_class = UserPassesTestLoginRequiredView
-    view_url = '/chained_view/'
+    view_url = "/chained_view/"
 
     def assert_redirect_to_login(self, response):
         """
         Check that the response is a redirect to the login view.
         """
         assert response.status_code == 302
-        assert response['Location'] == '/accounts/login/?next=/chained_view/'
+        assert response["Location"] == "/accounts/login/?next=/chained_view/"
 
     def test_anonymous(self):
         """
         Check that anonymous users redirect to login by default.
         """
-        resp = self.dispatch_view(
-            self.build_request(path=self.view_url))
+        resp = self.dispatch_view(self.build_request(path=self.view_url))
         self.assert_redirect_to_login(resp)
 
     def test_anonymous_raises_exception(self):
@@ -284,7 +299,8 @@ class TestChainedLoginRequiredMixin(TestViewHelper, test.TestCase):
         """
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
-                self.build_request(path=self.view_url), raise_exception=True)
+                self.build_request(path=self.view_url), raise_exception=True
+            )
 
     def test_authenticated_raises_exception(self):
         """
@@ -295,11 +311,14 @@ class TestChainedLoginRequiredMixin(TestViewHelper, test.TestCase):
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
                 self.build_request(path=self.view_url, user=user),
-                raise_exception=True)
+                raise_exception=True,
+            )
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
                 self.build_request(path=self.view_url, user=user),
-                raise_exception=True, redirect_unauthenticated_users=True)
+                raise_exception=True,
+                redirect_unauthenticated_users=True,
+            )
 
     def test_anonymous_redirects(self):
         """
@@ -307,8 +326,10 @@ class TestChainedLoginRequiredMixin(TestViewHelper, test.TestCase):
         is overridden by redirect_unauthenticated_users.
         """
         resp = self.dispatch_view(
-            self.build_request(path=self.view_url), raise_exception=True,
-            redirect_unauthenticated_users=True)
+            self.build_request(path=self.view_url),
+            raise_exception=True,
+            redirect_unauthenticated_users=True,
+        )
         self.assert_redirect_to_login(resp)
 
 
@@ -317,8 +338,9 @@ class TestAnonymousRequiredMixin(TestViewHelper, test.TestCase):
     """
     Tests for AnonymousRequiredMixin.
     """
+
     view_class = AnonymousRequiredView
-    view_url = '/unauthenticated_view/'
+    view_url = "/unauthenticated_view/"
 
     def test_anonymous(self):
         """
@@ -327,14 +349,14 @@ class TestAnonymousRequiredMixin(TestViewHelper, test.TestCase):
         """
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
         # Test with reverse_lazy
         resp = self.dispatch_view(
-            self.build_request(),
-            login_url=reverse_lazy(self.view_url))
+            self.build_request(), login_url=reverse_lazy(self.view_url)
+        )
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
     def test_authenticated(self):
         """
@@ -342,24 +364,24 @@ class TestAnonymousRequiredMixin(TestViewHelper, test.TestCase):
         to the approparite view.
         """
         user = UserFactory()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
         self.assertEqual(302, resp.status_code)
 
         resp = self.client.get(self.view_url, follow=True)
-        self.assertRedirects(resp, '/authenticated_view/')
+        self.assertRedirects(resp, "/authenticated_view/")
 
     def test_no_url(self):
         self.view_class.authenticated_redirect_url = None
         user = UserFactory()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         with self.assertRaises(ImproperlyConfigured):
             self.client.get(self.view_url)
 
     def test_bad_url(self):
-        self.view_class.authenticated_redirect_url = '/epicfailurl/'
+        self.view_class.authenticated_redirect_url = "/epicfailurl/"
         user = UserFactory()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url, follow=True)
         self.assertEqual(404, resp.status_code)
 
@@ -369,11 +391,12 @@ class TestPermissionRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     """
     Tests for PermissionRequiredMixin.
     """
+
     view_class = PermissionRequiredView
-    view_url = '/permission_required/'
+    view_url = "/permission_required/"
 
     def build_authorized_user(self):
-        return UserFactory(permissions=['auth.add_user'])
+        return UserFactory(permissions=["auth.add_user"])
 
     def build_unauthorized_user(self):
         return UserFactory()
@@ -389,38 +412,43 @@ class TestPermissionRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
 
 @pytest.mark.django_db
 class TestMultiplePermissionsRequiredMixin(
-        _TestAccessBasicsMixin, test.TestCase):
+    _TestAccessBasicsMixin, test.TestCase
+):
     view_class = MultiplePermissionsRequiredView
-    view_url = '/multiple_permissions_required/'
+    view_url = "/multiple_permissions_required/"
 
     def build_authorized_user(self):
-        return UserFactory(permissions=[
-            'tests.add_article', 'tests.change_article', 'auth.change_user'])
+        return UserFactory(
+            permissions=[
+                "tests.add_article",
+                "tests.change_article",
+                "auth.change_user",
+            ]
+        )
 
     def build_unauthorized_user(self):
-        return UserFactory(permissions=['tests.add_article'])
+        return UserFactory(permissions=["tests.add_article"])
 
     def test_redirects_to_login(self):
         """
         User should be redirected to login page if he or she does not have
         sufficient permissions.
         """
-        url = '/multiple_permissions_required/'
+        url = "/multiple_permissions_required/"
         test_cases = (
             # missing one permission from 'any'
-            ['tests.add_article', 'tests.change_article'],
+            ["tests.add_article", "tests.change_article"],
             # missing one permission from 'all'
-            ['tests.add_article', 'auth.add_user'],
+            ["tests.add_article", "auth.add_user"],
             # no permissions at all
             [],
         )
 
         for permissions in test_cases:
             user = UserFactory(permissions=permissions)
-            self.client.login(username=user.username, password='asdf1234')
+            self.client.login(username=user.username, password="asdf1234")
             resp = self.client.get(url)
-            self.assertRedirects(resp, '/accounts/login/?next={0}'.format(
-                url))
+            self.assertRedirects(resp, "/accounts/login/?next={0}".format(url))
 
     def test_invalid_permissions(self):
         """
@@ -431,10 +459,10 @@ class TestMultiplePermissionsRequiredMixin(
             None,  # permissions must be set
             (),  # and they must be a dict
             {},  # at least one of 'all', 'any' keys must be present
-            {'all': None},  # both all and any must be list or a tuple
-            {'all': {'a': 1}},
-            {'any': None},
-            {'any': {'a': 1}},
+            {"all": None},  # both all and any must be list or a tuple
+            {"all": {"a": 1}},
+            {"any": None},
+            {"any": {"a": 1}},
         )
 
         for attr in permissions:
@@ -448,9 +476,9 @@ class TestMultiplePermissionsRequiredMixin(
         """
         test_cases = (
             # missing one permission from 'any'
-            ['tests.add_article', 'tests.change_article'],
+            ["tests.add_article", "tests.change_article"],
             # missing one permission from 'all'
-            ['tests.add_article', 'auth.add_user'],
+            ["tests.add_article", "auth.add_user"],
             # no permissions at all
             [],
         )
@@ -465,41 +493,45 @@ class TestMultiplePermissionsRequiredMixin(
         """
         Tests if everything works if only 'all' permissions has been set.
         """
-        permissions = {'all': ['auth.add_user', 'tests.add_article']}
-        user = UserFactory(permissions=permissions['all'])
+        permissions = {"all": ["auth.add_user", "tests.add_article"]}
+        user = UserFactory(permissions=permissions["all"])
         req = self.build_request(user=user)
 
         resp = self.dispatch_view(req, permissions=permissions)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
-        user = UserFactory(permissions=['auth.add_user'])
+        user = UserFactory(permissions=["auth.add_user"])
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
-                self.build_request(user=user), raise_exception=True,
-                permissions=permissions)
+                self.build_request(user=user),
+                raise_exception=True,
+                permissions=permissions,
+            )
 
     def test_any_permissions_key(self):
         """
         Tests if everything works if only 'any' permissions has been set.
         """
-        permissions = {'any': ['auth.add_user', 'tests.add_article']}
-        user = UserFactory(permissions=['tests.add_article'])
+        permissions = {"any": ["auth.add_user", "tests.add_article"]}
+        user = UserFactory(permissions=["tests.add_article"])
         req = self.build_request(user=user)
 
         resp = self.dispatch_view(req, permissions=permissions)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
         user = UserFactory(permissions=[])
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
-                self.build_request(user=user), raise_exception=True,
-                permissions=permissions)
+                self.build_request(user=user),
+                raise_exception=True,
+                permissions=permissions,
+            )
 
 
 @pytest.mark.django_db
 class TestSuperuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = SuperuserRequiredView
-    view_url = '/superuser_required/'
+    view_url = "/superuser_required/"
 
     def build_authorized_user(self):
         return UserFactory(is_superuser=True, is_staff=True)
@@ -511,7 +543,7 @@ class TestSuperuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
 @pytest.mark.django_db
 class TestStaffuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = StaffuserRequiredView
-    view_url = '/staffuser_required/'
+    view_url = "/staffuser_required/"
 
     def build_authorized_user(self):
         return UserFactory(is_staff=True)
@@ -523,11 +555,11 @@ class TestStaffuserRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
 @pytest.mark.django_db
 class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = GroupRequiredView
-    view_url = '/group_required/'
+    view_url = "/group_required/"
 
     def build_authorized_user(self):
         user = UserFactory()
-        group = GroupFactory(name='test_group')
+        group = GroupFactory(name="test_group")
         user.groups.add(group)
         return user
 
@@ -541,33 +573,33 @@ class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         return UserFactory()
 
     def test_with_string(self):
-        self.assertEqual('test_group', self.view_class.group_required)
+        self.assertEqual("test_group", self.view_class.group_required)
         user = self.build_authorized_user()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
     def test_with_group_list(self):
-        group_list = ['test_group', 'editors']
+        group_list = ["test_group", "editors"]
         # the test client will instantiate a new view on request, so we have to
         # modify the class variable (and restore it when the test finished)
         self.view_class.group_required = group_list
         self.assertEqual(group_list, self.view_class.group_required)
         user = self.build_authorized_user()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
-        self.view_class.group_required = 'test_group'
-        self.assertEqual('test_group', self.view_class.group_required)
+        self.assertEqual("OK", force_str(resp.content))
+        self.view_class.group_required = "test_group"
+        self.assertEqual("test_group", self.view_class.group_required)
 
     def test_superuser_allowed(self):
         user = self.build_superuser()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
     def test_improperly_configured(self):
         view = self.view_class()
@@ -575,84 +607,87 @@ class TestGroupRequiredMixin(_TestAccessBasicsMixin, test.TestCase):
         with self.assertRaises(ImproperlyConfigured):
             view.get_group_required()
 
-        view.group_required = {'foo': 'bar'}
+        view.group_required = {"foo": "bar"}
         with self.assertRaises(ImproperlyConfigured):
             view.get_group_required()
 
     def test_with_unicode(self):
-        self.view_class.group_required = 'niño'
-        self.assertEqual('niño', self.view_class.group_required)
+        self.view_class.group_required = "niño"
+        self.assertEqual("niño", self.view_class.group_required)
 
         user = self.build_authorized_user()
         group = user.groups.all()[0]
-        group.name = 'niño'
+        group.name = "niño"
         group.save()
-        self.assertEqual('niño', user.groups.all()[0].name)
+        self.assertEqual("niño", user.groups.all()[0].name)
 
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
-        self.view_class.group_required = 'test_group'
-        self.assertEqual('test_group', self.view_class.group_required)
+        self.assertEqual("OK", force_str(resp.content))
+        self.view_class.group_required = "test_group"
+        self.assertEqual("test_group", self.view_class.group_required)
 
 
 @pytest.mark.django_db
 class TestUserPassesTestMixin(_TestAccessBasicsMixin, test.TestCase):
     view_class = UserPassesTestView
-    view_url = '/user_passes_test/'
+    view_url = "/user_passes_test/"
     view_not_implemented_class = UserPassesTestNotImplementedView
-    view_not_implemented_url = '/user_passes_test_not_implemented/'
+    view_not_implemented_url = "/user_passes_test_not_implemented/"
 
     # for testing with passing and not passsing func_test
     def build_authorized_user(self, is_superuser=False):
-        return UserFactory(is_superuser=is_superuser, is_staff=True,
-                           email="user@mydomain.com")
+        return UserFactory(
+            is_superuser=is_superuser, is_staff=True, email="user@mydomain.com"
+        )
 
     def build_unauthorized_user(self):
         return UserFactory()
 
     def test_with_user_pass(self):
         user = self.build_authorized_user()
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
 
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('OK', force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
     def test_with_user_not_pass(self):
         user = self.build_authorized_user(is_superuser=True)
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.view_url)
 
-        self.assertRedirects(resp, '/accounts/login/?next=/user_passes_test/')
+        self.assertRedirects(resp, "/accounts/login/?next=/user_passes_test/")
 
     def test_with_user_raise_exception(self):
         with self.assertRaises(PermissionDenied):
             self.dispatch_view(
-                self.build_request(path=self.view_url), raise_exception=True)
+                self.build_request(path=self.view_url), raise_exception=True
+            )
 
     def test_not_implemented(self):
         view = self.view_not_implemented_class()
         with self.assertRaises(NotImplementedError):
             view.dispatch(
                 self.build_request(path=self.view_not_implemented_url),
-                raise_exception=True)
+                raise_exception=True,
+            )
 
 
 @pytest.mark.django_db
 class TestSSLRequiredMixin(test.TestCase):
     view_class = SSLRequiredView
-    view_url = '/sslrequired/'
+    view_url = "/sslrequired/"
 
     def test_ssl_redirection(self):
-        self.view_url = 'https://testserver' + self.view_url
+        self.view_url = "https://testserver" + self.view_url
         self.view_class.raise_exception = False
         resp = self.client.get(self.view_url)
         self.assertRedirects(resp, self.view_url, status_code=301)
         resp = self.client.get(self.view_url, follow=True)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('https', resp.request.get('wsgi.url_scheme'))
+        self.assertEqual("https", resp.request.get("wsgi.url_scheme"))
 
     def test_raises_exception(self):
         self.view_class.raise_exception = True
@@ -669,7 +704,7 @@ class TestSSLRequiredMixin(test.TestCase):
         self.view_class.raise_exception = False
         resp = self.client.get(self.view_url, secure=True)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual('https', resp.request.get('wsgi.url_scheme'))
+        self.assertEqual("https", resp.request.get("wsgi.url_scheme"))
 
 
 @pytest.mark.django_db
@@ -677,26 +712,27 @@ class TestRecentLoginRequiredMixin(test.TestCase):
     """
     Tests for RecentLoginRequiredMixin.
     """
+
     view_class = RecentLoginRequiredView
-    recent_view_url = '/recent_login/'
-    outdated_view_url = '/outdated_login/'
+    recent_view_url = "/recent_login/"
+    outdated_view_url = "/outdated_login/"
 
     def test_recent_login(self):
         self.view_class.max_last_login_delta = 1800
         last_login = datetime.datetime.now()
         last_login = make_aware(last_login, get_current_timezone())
         user = UserFactory(last_login=last_login)
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.recent_view_url)
         assert resp.status_code == 200
-        assert force_string(resp.content) == 'OK'
+        assert force_str(resp.content) == "OK"
 
     def test_outdated_login(self):
         self.view_class.max_last_login_delta = 0
         last_login = datetime.datetime.now() - datetime.timedelta(hours=2)
         last_login = make_aware(last_login, get_current_timezone())
         user = UserFactory(last_login=last_login)
-        self.client.login(username=user.username, password='asdf1234')
+        self.client.login(username=user.username, password="asdf1234")
         resp = self.client.get(self.outdated_view_url)
         assert resp.status_code == 302
 
