@@ -1,26 +1,24 @@
-from __future__ import absolute_import, unicode_literals
-
 import json
 import mock
 
 from django import test
 from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpResponse
+from django.utils.encoding import force_str
 
 from braces.views import AjaxResponseMixin
 
-from .compat import force_string
 from .factories import ArticleFactory, UserFactory
 from .helpers import TestViewHelper
-from .views import (SimpleJsonView, JsonRequestResponseView,
-                    JsonBadRequestView)
+from .views import SimpleJsonView, JsonRequestResponseView, JsonBadRequestView
 
 
 class TestAjaxResponseMixin(TestViewHelper, test.TestCase):
     """
     Tests for AjaxResponseMixin.
     """
-    methods = ['get', 'post', 'put', 'delete']
+
+    methods = ["get", "post", "put", "delete"]
 
     def test_xhr(self):
         """
@@ -29,8 +27,10 @@ class TestAjaxResponseMixin(TestViewHelper, test.TestCase):
         # AjaxResponseView returns 'AJAX_OK' when requested with XmlHttpRequest
         for m in self.methods:
             fn = getattr(self.client, m)
-            resp = fn('/ajax_response/', HTTP_X_REQUESTED_WITH='XMLHttpRequest')
-            assert force_string(resp.content) == 'AJAX_OK'
+            resp = fn(
+                "/ajax_response/", HTTP_X_REQUESTED_WITH="XMLHttpRequest"
+            )
+            assert force_str(resp.content) == "AJAX_OK"
 
     def test_not_xhr(self):
         """
@@ -39,18 +39,18 @@ class TestAjaxResponseMixin(TestViewHelper, test.TestCase):
         """
         for m in self.methods:
             fn = getattr(self.client, m)
-            resp = fn('/ajax_response/')
-            assert force_string(resp.content) == 'OK'
+            resp = fn("/ajax_response/")
+            assert force_str(resp.content) == "OK"
 
     def test_fallback_to_normal_methods(self):
         """
         Ajax methods should fallback to normal methods by default.
         """
         test_cases = [
-            ('get', 'get'),
-            ('post', 'post'),
-            ('put', 'get'),
-            ('delete', 'get'),
+            ("get", "get"),
+            ("post", "post"),
+            ("put", "get"),
+            ("delete", "get"),
         ]
 
         for ajax_method, fallback in test_cases:
@@ -70,12 +70,14 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
     """
     Tests for JSONResponseMixin.
     """
+
     view_class = SimpleJsonView
 
     def assert_json_response(self, resp, status_code=200):
         self.assertEqual(status_code, resp.status_code)
-        self.assertEqual('application/json',
-                         resp['content-type'].split(';')[0])
+        self.assertEqual(
+            "application/json", resp["content-type"].split(";")[0]
+        )
 
     def get_content(self, url):
         """
@@ -83,7 +85,7 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         """
         resp = self.client.get(url)
         self.assert_json_response(resp)
-        content = force_string(resp.content)
+        content = force_str(resp.content)
         return content
 
     def test_simple_json(self):
@@ -91,9 +93,9 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         Tests render_json_response() method.
         """
         user = UserFactory()
-        self.client.login(username=user.username, password='asdf1234')
-        data = json.loads(self.get_content('/simple_json/'))
-        self.assertEqual({'username': user.username}, data)
+        self.client.login(username=user.username, password="asdf1234")
+        data = json.loads(self.get_content("/simple_json/"))
+        self.assertEqual({"username": user.username}, data)
 
     def test_serialization(self):
         """
@@ -101,14 +103,14 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         using django's serializer framework.
         """
         a1, a2 = [ArticleFactory() for __ in range(2)]
-        data = json.loads(self.get_content('/article_list_json/'))
+        data = json.loads(self.get_content("/article_list_json/"))
         self.assertIsInstance(data, list)
         self.assertEqual(2, len(data))
         titles = []
         for row in data:
             # only title has been serialized
-            self.assertEqual(1, len(row['fields']))
-            titles.append(row['fields']['title'])
+            self.assertEqual(1, len(row["fields"]))
+            titles.append(row["fields"]["title"])
 
         self.assertIn(a1.title, titles)
         self.assertIn(a2.title, titles)
@@ -119,7 +121,7 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         attribute is not set correctly.
         """
         with self.assertRaises(ImproperlyConfigured):
-            self.dispatch_view(self.build_request(), content_type=['a'])
+            self.dispatch_view(self.build_request(), content_type=["a"])
 
     def test_pretty_json(self):
         """
@@ -127,12 +129,12 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         is longer than the normal one.
         """
         user = UserFactory()
-        self.client.login(username=user.username, password='asfa')
-        normal_content = self.get_content('/simple_json/')
-        self.view_class.json_dumps_kwargs = {'indent': 2}
-        pretty_content = self.get_content('/simple_json/')
-        normal_json = json.loads('{0}'.format(normal_content))
-        pretty_json = json.loads('{0}'.format(pretty_content))
+        self.client.login(username=user.username, password="asfa")
+        normal_content = self.get_content("/simple_json/")
+        self.view_class.json_dumps_kwargs = {"indent": 2}
+        pretty_content = self.get_content("/simple_json/")
+        normal_json = json.loads("{0}".format(normal_content))
+        pretty_json = json.loads("{0}".format(pretty_content))
         self.assertEqual(normal_json, pretty_json)
         self.assertTrue(len(pretty_content) > len(normal_content))
 
@@ -140,25 +142,23 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         """
         Tests setting custom `json_encoder_class` attribute.
         """
-        data = json.loads(self.get_content('/simple_json_custom_encoder/'))
-        self.assertEqual({'numbers': [1, 2, 3]}, data)
+        data = json.loads(self.get_content("/simple_json_custom_encoder/"))
+        self.assertEqual({"numbers": [1, 2, 3]}, data)
 
 
 class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
     view_class = JsonRequestResponseView
-    request_dict = {'status': 'operational'}
+    request_dict = {"status": "operational"}
 
     def test_get_request_json_properly_formatted(self):
         """
         Properly formatted JSON requests should result in a JSON object
         """
-        data = json.dumps(self.request_dict).encode('utf-8')
+        data = json.dumps(self.request_dict).encode("utf-8")
         response = self.client.post(
-            '/json_request/',
-            content_type='application/json',
-            data=data
+            "/json_request/", content_type="application/json", data=data
         )
-        response_json = json.loads(response.content.decode('utf-8'))
+        response_json = json.loads(response.content.decode("utf-8"))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response_json, self.request_dict)
 
@@ -166,11 +166,8 @@ class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
         """
         Improperly formatted JSON requests should make request_json == None
         """
-        response = self.client.post(
-            '/json_request/',
-            data=self.request_dict
-        )
-        response_json = json.loads(response.content.decode('utf-8'))
+        response = self.client.post("/json_request/", data=self.request_dict)
+        response_json = json.loads(response.content.decode("utf-8"))
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response_json, None)
 
@@ -180,17 +177,16 @@ class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
         or None, the client should get a 400 error
         """
         response = self.client.post(
-            '/json_custom_bad_request/',
-            data=self.request_dict
+            "/json_custom_bad_request/", data=self.request_dict
         )
-        response_json = json.loads(response.content.decode('utf-8'))
+        response_json = json.loads(response.content.decode("utf-8"))
         self.assertEqual(response.status_code, 400)
-        self.assertEqual(response_json, {'error': 'you messed up'})
+        self.assertEqual(response_json, {"error": "you messed up"})
 
 
 class TestJsonBadRequestMixin(TestViewHelper, test.TestCase):
     view_class = JsonBadRequestView
-    request_dict = {'status': 'operational'}
+    request_dict = {"status": "operational"}
 
     def test_bad_request_response(self):
         """
@@ -198,10 +194,9 @@ class TestJsonBadRequestMixin(TestViewHelper, test.TestCase):
         or None, the client should get a 400 error
         """
         response = self.client.post(
-            '/json_bad_request/',
-            data=self.request_dict
+            "/json_bad_request/", data=self.request_dict
         )
-        response_json = json.loads(response.content.decode('utf-8'))
+        response_json = json.loads(response.content.decode("utf-8"))
         self.assertEqual(response.status_code, 400)
         self.assertEqual(response_json, self.view_class.error_response_dict)
 
@@ -213,8 +208,5 @@ class TestJsonBadRequestMixin(TestViewHelper, test.TestCase):
         * it's not possible to send HTTP body within an OPTIONS request
         * it's not up to an OPTIONS request to decide if the payload is valid
         """
-        response = self.client.options(
-            '/json_bad_request/',
-            data=None
-        )
+        response = self.client.options("/json_bad_request/", data=None)
         self.assertEqual(response.status_code, 200)
