@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import mock
 import pytest
 
@@ -12,73 +9,85 @@ from django.http import HttpResponse
 from django import test
 from django.test.utils import override_settings
 from django.views.generic import View
+from django.utils.encoding import force_str
 
-from braces.views import (SetHeadlineMixin, MessageMixin, FormValidMessageMixin,
-                          FormInvalidMessageMixin)
-from .compat import force_string
+from braces.views import (
+    SetHeadlineMixin,
+    MessageMixin,
+    FormValidMessageMixin,
+    FormInvalidMessageMixin,
+)
 from .factories import UserFactory
 from .helpers import TestViewHelper
 from .models import Article, CanonicalArticle
-from .views import (ArticleListView, ArticleListViewWithCustomQueryset,
-                    AuthorDetailView, OrderableListView,
-                    FormMessagesView, ContextView)
+from .views import (
+    ArticleListView,
+    ArticleListViewWithCustomQueryset,
+    AuthorDetailView,
+    OrderableListView,
+    FormMessagesView,
+    ContextView,
+)
 
 
 class TestSuccessURLRedirectListMixin(test.TestCase):
     """
     Tests for SuccessURLRedirectListMixin.
     """
+
     def test_redirect(self):
         """
         Test if browser is redirected to list view.
         """
-        data = {'title': "Test body", 'body': "Test body"}
-        resp = self.client.post('/article_list/create/', data)
-        self.assertRedirects(resp, '/article_list/')
+        data = {"title": "Test body", "body": "Test body"}
+        resp = self.client.post("/article_list/create/", data)
+        self.assertRedirects(resp, "/article_list/")
 
     def test_no_url_name(self):
         """
         Test that ImproperlyConfigured is raised.
         """
-        data = {'title': "Test body", 'body': "Test body"}
+        data = {"title": "Test body", "body": "Test body"}
         with self.assertRaises(ImproperlyConfigured):
-            self.client.post('/article_list_bad/create/', data)
+            self.client.post("/article_list_bad/create/", data)
 
 
 class TestUserFormKwargsMixin(test.TestCase):
     """
     Tests for UserFormKwargsMixin.
     """
+
     def test_post_method(self):
         user = UserFactory()
-        self.client.login(username=user.username, password='asdf1234')
-        resp = self.client.post('/form_with_user_kwarg/', {'field1': 'foo'})
-        assert force_string(resp.content) == "username: %s" % user.username
+        self.client.login(username=user.username, password="asdf1234")
+        resp = self.client.post("/form_with_user_kwarg/", {"field1": "foo"})
+        assert force_str(resp.content) == "username: %s" % user.username
 
     def test_get_method(self):
         user = UserFactory()
-        self.client.login(username=user.username, password='asdf1234')
-        resp = self.client.get('/form_with_user_kwarg/')
-        assert resp.context['form'].user == user
+        self.client.login(username=user.username, password="asdf1234")
+        resp = self.client.get("/form_with_user_kwarg/")
+        assert resp.context["form"].user == user
 
 
 class TestSetHeadlineMixin(test.TestCase):
     """
     Tests for SetHeadlineMixin.
     """
+
     def test_dynamic_headline(self):
         """
         Tests if get_headline() is called properly.
         """
-        resp = self.client.get('/headline/test-headline/')
-        self.assertEqual('test-headline', resp.context['headline'])
+        resp = self.client.get("/headline/test-headline/")
+        self.assertEqual("test-headline", resp.context["headline"])
 
     def test_context_data(self):
         """
         Tests if mixin adds proper headline to template context.
         """
-        resp = self.client.get('/headline/foo-bar/')
-        self.assertEqual("foo-bar", resp.context['headline'])
+        resp = self.client.get("/headline/foo-bar/")
+        self.assertEqual("foo-bar", resp.context["headline"])
 
     def test_get_headline(self):
         """
@@ -92,27 +101,28 @@ class TestSetHeadlineMixin(test.TestCase):
         self.assertEqual("Test headline", mixin.get_headline())
 
     def test_get_headline_lazy(self):
-        resp = self.client.get('/headline/lazy/')
-        self.assertEqual('Test Headline', resp.context['headline'])
+        resp = self.client.get("/headline/lazy/")
+        self.assertEqual("Test Headline", resp.context["headline"])
 
 
 class TestStaticContextMixin(test.TestCase):
-    """ Tests for StaticContextMixin. """
+    """Tests for StaticContextMixin."""
+
     view_class = ContextView
-    view_url = '/context/'
+    view_url = "/context/"
 
     def test_dict(self):
-        self.view_class.static_context = {'test': True}
+        self.view_class.static_context = {"test": True}
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual(True, resp.context['test'])
+        self.assertEqual(True, resp.context["test"])
 
     def test_two_tuple(self):
-        self.view_class.static_context = [('a', 1), ('b', 2)]
+        self.view_class.static_context = [("a", 1), ("b", 2)]
         resp = self.client.get(self.view_url)
         self.assertEqual(200, resp.status_code)
-        self.assertEqual(1, resp.context['a'])
-        self.assertEqual(2, resp.context['b'])
+        self.assertEqual(1, resp.context["a"])
+        self.assertEqual(2, resp.context["b"])
 
     def test_not_set(self):
         self.view_class.static_context = None
@@ -120,12 +130,12 @@ class TestStaticContextMixin(test.TestCase):
             self.client.get(self.view_url)
 
     def test_string_value_error(self):
-        self.view_class.static_context = 'Fail'
+        self.view_class.static_context = "Fail"
         with self.assertRaises(ImproperlyConfigured):
             self.client.get(self.view_url)
 
     def test_list_error(self):
-        self.view_class.static_context = ['fail', 'fail']
+        self.view_class.static_context = ["fail", "fail"]
         with self.assertRaises(ImproperlyConfigured):
             self.client.get(self.view_url)
 
@@ -134,6 +144,7 @@ class TestCsrfExemptMixin(test.TestCase):
     """
     Tests for TestCsrfExemptMixin.
     """
+
     def setUp(self):
         super(TestCsrfExemptMixin, self).setUp()
         self.client = self.client_class(enforce_csrf_checks=True)
@@ -142,9 +153,9 @@ class TestCsrfExemptMixin(test.TestCase):
         """
         Tests if csrf token is not required.
         """
-        resp = self.client.post('/csrf_exempt/', {'field1': 'test'})
+        resp = self.client.post("/csrf_exempt/", {"field1": "test"})
         self.assertEqual(200, resp.status_code)
-        self.assertEqual("OK", force_string(resp.content))
+        self.assertEqual("OK", force_str(resp.content))
 
 
 class TestSelectRelatedMixin(TestViewHelper, test.TestCase):
@@ -165,24 +176,24 @@ class TestSelectRelatedMixin(TestViewHelper, test.TestCase):
         :return:
         """
         with self.assertRaises(ImproperlyConfigured):
-            self.dispatch_view(self.build_request(), select_related={'a': 1})
+            self.dispatch_view(self.build_request(), select_related={"a": 1})
 
-    @mock.patch('django.db.models.query.QuerySet.select_related')
+    @mock.patch("django.db.models.query.QuerySet.select_related")
     def test_select_related_called(self, m):
         """
         Checks if QuerySet's select_related() was called with correct
         arguments.
         """
         qs = Article.objects.all()
-        m.return_value = qs.select_related('author')
+        m.return_value = qs.select_related("author")
         qs.select_related = m
         m.reset_mock()
 
         resp = self.dispatch_view(self.build_request())
         self.assertEqual(200, resp.status_code)
-        m.assert_called_once_with('author')
+        m.assert_called_once_with("author")
 
-    @mock.patch('django.db.models.query.QuerySet.select_related')
+    @mock.patch("django.db.models.query.QuerySet.select_related")
     def test_select_related_keeps_select_related_from_queryset(self, m):
         """
         Checks that an empty select_related attribute does not
@@ -195,7 +206,8 @@ class TestSelectRelatedMixin(TestViewHelper, test.TestCase):
         with pytest.warns(UserWarning):
             resp = self.dispatch_view(
                 self.build_request(),
-                view_class=ArticleListViewWithCustomQueryset)
+                view_class=ArticleListViewWithCustomQueryset,
+            )
         self.assertEqual(200, resp.status_code)
         self.assertEqual(0, m.call_count)
 
@@ -218,24 +230,24 @@ class TestPrefetchRelatedMixin(TestViewHelper, test.TestCase):
         :return:
         """
         with self.assertRaises(ImproperlyConfigured):
-            self.dispatch_view(self.build_request(), prefetch_related={'a': 1})
+            self.dispatch_view(self.build_request(), prefetch_related={"a": 1})
 
-    @mock.patch('django.db.models.query.QuerySet.prefetch_related')
+    @mock.patch("django.db.models.query.QuerySet.prefetch_related")
     def test_prefetch_related_called(self, m):
         """
         Checks if QuerySet's prefetch_related() was called with correct
         arguments.
         """
         qs = Article.objects.all()
-        m.return_value = qs.prefetch_related('article_set')
+        m.return_value = qs.prefetch_related("article_set")
         qs.prefetch_related = m
         m.reset_mock()
 
         resp = self.dispatch_view(self.build_request())
         self.assertEqual(200, resp.status_code)
-        m.assert_called_once_with('article_set')
+        m.assert_called_once_with("article_set")
 
-    @mock.patch('django.db.models.query.QuerySet.prefetch_related')
+    @mock.patch("django.db.models.query.QuerySet.prefetch_related")
     def test_prefetch_related_keeps_select_related_from_queryset(self, m):
         """
         Checks that an empty prefetch_related attribute does not
@@ -248,7 +260,8 @@ class TestPrefetchRelatedMixin(TestViewHelper, test.TestCase):
         with pytest.warns(UserWarning):
             resp = self.dispatch_view(
                 self.build_request(),
-                view_class=ArticleListViewWithCustomQueryset)
+                view_class=ArticleListViewWithCustomQueryset,
+            )
         self.assertEqual(200, resp.status_code)
         self.assertEqual(0, m.call_count)
 
@@ -257,8 +270,8 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
     view_class = OrderableListView
 
     def __make_test_articles(self):
-        a1 = Article.objects.create(title='Alpha', body='Zet')
-        a2 = Article.objects.create(title='Zet', body='Alpha')
+        a1 = Article.objects.create(title="Alpha", body="Zet")
+        a2 = Article.objects.create(title="Zet", body="Alpha")
         return a1, a2
 
     def test_correct_order(self):
@@ -268,16 +281,24 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         a1, a2 = self.__make_test_articles()
 
         resp = self.dispatch_view(
-            self.build_request(path='?order_by=title&ordering=asc'),
+            self.build_request(path="?order_by=title&ordering=asc"),
             orderable_columns=None,
-            get_orderable_columns=lambda: ('id', 'title', ))
-        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+            get_orderable_columns=lambda: (
+                "id",
+                "title",
+            ),
+        )
+        self.assertEqual(list(resp.context_data["object_list"]), [a1, a2])
 
         resp = self.dispatch_view(
-            self.build_request(path='?order_by=id&ordering=desc'),
+            self.build_request(path="?order_by=id&ordering=desc"),
             orderable_columns=None,
-            get_orderable_columns=lambda: ('id', 'title', ))
-        self.assertEqual(list(resp.context_data['object_list']), [a2, a1])
+            get_orderable_columns=lambda: (
+                "id",
+                "title",
+            ),
+        )
+        self.assertEqual(list(resp.context_data["object_list"]), [a2, a1])
 
     def test_correct_order_with_default_ordering(self):
         """
@@ -287,25 +308,37 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         a1, a2 = self.__make_test_articles()
 
         resp = self.dispatch_view(
-            self.build_request(path='?order_by=id'),
+            self.build_request(path="?order_by=id"),
             orderable_columns=None,
             ordering_default=None,
-            get_orderable_columns=lambda: ('id', 'title', ))
-        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+            get_orderable_columns=lambda: (
+                "id",
+                "title",
+            ),
+        )
+        self.assertEqual(list(resp.context_data["object_list"]), [a1, a2])
 
         resp = self.dispatch_view(
-            self.build_request(path='?order_by=id'),
+            self.build_request(path="?order_by=id"),
             orderable_columns=None,
             ordering_default="asc",
-            get_orderable_columns=lambda: ('id', 'title', ))
-        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+            get_orderable_columns=lambda: (
+                "id",
+                "title",
+            ),
+        )
+        self.assertEqual(list(resp.context_data["object_list"]), [a1, a2])
 
         resp = self.dispatch_view(
-            self.build_request(path='?order_by=id'),
+            self.build_request(path="?order_by=id"),
             orderable_columns=None,
             ordering_default="desc",
-            get_orderable_columns=lambda: ('id', 'title', ))
-        self.assertEqual(list(resp.context_data['object_list']), [a2, a1])
+            get_orderable_columns=lambda: (
+                "id",
+                "title",
+            ),
+        )
+        self.assertEqual(list(resp.context_data["object_list"]), [a2, a1])
 
     def test_correct_order_with_param_not_default_ordering(self):
         """
@@ -316,11 +349,15 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         a1, a2 = self.__make_test_articles()
 
         resp = self.dispatch_view(
-            self.build_request(path='?order_by=id&ordering=asc'),
+            self.build_request(path="?order_by=id&ordering=asc"),
             orderable_columns=None,
-            ordering_default='desc',
-            get_orderable_columns=lambda: ('id', 'title', ))
-        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+            ordering_default="desc",
+            get_orderable_columns=lambda: (
+                "id",
+                "title",
+            ),
+        )
+        self.assertEqual(list(resp.context_data["object_list"]), [a1, a2])
 
     def test_correct_order_with_incorrect_default_ordering(self):
         """
@@ -329,8 +366,9 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         """
         view = self.view_class()
         view.ordering_default = "improper_default_value"
-        self.assertRaises(ImproperlyConfigured,
-                          lambda: view.get_ordering_default())
+        self.assertRaises(
+            ImproperlyConfigured, lambda: view.get_ordering_default()
+        )
 
     def test_default_column(self):
         """
@@ -340,7 +378,7 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         a1, a2 = self.__make_test_articles()
 
         resp = self.dispatch_view(self.build_request())
-        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+        self.assertEqual(list(resp.context_data["object_list"]), [a1, a2])
 
     def test_get_orderable_columns_returns_correct_values(self):
         """
@@ -351,8 +389,9 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         view = self.view_class()
         self.assertEqual(view.get_orderable_columns(), view.orderable_columns)
         view.orderable_columns = None
-        self.assertRaises(ImproperlyConfigured,
-                          lambda: view.get_orderable_columns())
+        self.assertRaises(
+            ImproperlyConfigured, lambda: view.get_orderable_columns()
+        )
 
     def test_get_orderable_columns_default_returns_correct_values(self):
         """
@@ -361,11 +400,14 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         ImproperlyConfigured exception in the attribute is None
         """
         view = self.view_class()
-        self.assertEqual(view.get_orderable_columns_default(),
-                         view.orderable_columns_default)
+        self.assertEqual(
+            view.get_orderable_columns_default(),
+            view.orderable_columns_default,
+        )
         view.orderable_columns_default = None
-        self.assertRaises(ImproperlyConfigured,
-                          lambda: view.get_orderable_columns_default())
+        self.assertRaises(
+            ImproperlyConfigured, lambda: view.get_orderable_columns_default()
+        )
 
     def test_only_allowed_columns(self):
         """
@@ -375,50 +417,51 @@ class TestOrderableListMixin(TestViewHelper, test.TestCase):
         a1, a2 = self.__make_test_articles()
 
         resp = self.dispatch_view(
-            self.build_request(path='?order_by=body&ordering=asc'),
+            self.build_request(path="?order_by=body&ordering=asc"),
             orderable_columns_default=None,
-            get_orderable_columns_default=lambda: 'title')
-        self.assertEqual(list(resp.context_data['object_list']), [a1, a2])
+            get_orderable_columns_default=lambda: "title",
+        )
+        self.assertEqual(list(resp.context_data["object_list"]), [a1, a2])
 
 
 class TestCanonicalSlugDetailView(test.TestCase):
     def setUp(self):
-        Article.objects.create(title='Alpha', body='Zet', slug='alpha')
-        Article.objects.create(title='Zet', body='Alpha', slug='zet')
+        Article.objects.create(title="Alpha", body="Zet", slug="alpha")
+        Article.objects.create(title="Zet", body="Alpha", slug="zet")
 
     def test_canonical_slug(self):
         """
         Test that no redirect occurs when slug is canonical.
         """
-        resp = self.client.get('/article-canonical/1-alpha/')
+        resp = self.client.get("/article-canonical/1-alpha/")
         self.assertEqual(resp.status_code, 200)
-        resp = self.client.get('/article-canonical/2-zet/')
+        resp = self.client.get("/article-canonical/2-zet/")
         self.assertEqual(resp.status_code, 200)
 
     def test_non_canonical_slug(self):
         """
         Test that a redirect occurs when the slug is non-canonical.
         """
-        resp = self.client.get('/article-canonical/1-bad-slug/')
+        resp = self.client.get("/article-canonical/1-bad-slug/")
         self.assertEqual(resp.status_code, 301)
-        resp = self.client.get('/article-canonical/2-bad-slug/')
+        resp = self.client.get("/article-canonical/2-bad-slug/")
         self.assertEqual(resp.status_code, 301)
 
 
 class TestNamespaceAwareCanonicalSlugDetailView(test.TestCase):
     def setUp(self):
-        Article.objects.create(title='Alpha', body='Zet', slug='alpha')
-        Article.objects.create(title='Zet', body='Alpha', slug='zet')
+        Article.objects.create(title="Alpha", body="Zet", slug="alpha")
+        Article.objects.create(title="Zet", body="Alpha", slug="zet")
 
     def test_canonical_slug(self):
         """
         Test that no redirect occurs when slug is canonical.
         """
         resp = self.client.get(
-            '/article-canonical-namespaced/article/1-alpha/')
+            "/article-canonical-namespaced/article/1-alpha/"
+        )
         self.assertEqual(resp.status_code, 200)
-        resp = self.client.get(
-            '/article-canonical-namespaced/article/2-zet/')
+        resp = self.client.get("/article-canonical-namespaced/article/2-zet/")
         self.assertEqual(resp.status_code, 200)
 
     def test_non_canonical_slug(self):
@@ -427,99 +470,102 @@ class TestNamespaceAwareCanonicalSlugDetailView(test.TestCase):
         redirect is namespace aware.
         """
         resp = self.client.get(
-            '/article-canonical-namespaced/article/1-bad-slug/')
+            "/article-canonical-namespaced/article/1-bad-slug/"
+        )
         self.assertEqual(resp.status_code, 301)
         resp = self.client.get(
-            '/article-canonical-namespaced/article/2-bad-slug/')
+            "/article-canonical-namespaced/article/2-bad-slug/"
+        )
         self.assertEqual(resp.status_code, 301)
 
 
 class TestOverriddenCanonicalSlugDetailView(test.TestCase):
     def setUp(self):
-        Article.objects.create(title='Alpha', body='Zet', slug='alpha')
-        Article.objects.create(title='Zet', body='Alpha', slug='zet')
+        Article.objects.create(title="Alpha", body="Zet", slug="alpha")
+        Article.objects.create(title="Zet", body="Alpha", slug="zet")
 
     def test_canonical_slug(self):
         """
         Test that no redirect occurs when slug is canonical according to the
         overridden canonical slug.
         """
-        resp = self.client.get('/article-canonical-override/1-nycun/')
+        resp = self.client.get("/article-canonical-override/1-nycun/")
         self.assertEqual(resp.status_code, 200)
-        resp = self.client.get('/article-canonical-override/2-mrg/')
+        resp = self.client.get("/article-canonical-override/2-mrg/")
         self.assertEqual(resp.status_code, 200)
 
     def test_non_canonical_slug(self):
         """
         Test that a redirect occurs when the slug is non-canonical.
         """
-        resp = self.client.get('/article-canonical-override/1-bad-slug/')
+        resp = self.client.get("/article-canonical-override/1-bad-slug/")
         self.assertEqual(resp.status_code, 301)
-        resp = self.client.get('/article-canonical-override/2-bad-slug/')
+        resp = self.client.get("/article-canonical-override/2-bad-slug/")
         self.assertEqual(resp.status_code, 301)
 
 
 class TestCustomUrlKwargsCanonicalSlugDetailView(test.TestCase):
     def setUp(self):
-        Article.objects.create(title='Alpha', body='Zet', slug='alpha')
-        Article.objects.create(title='Zet', body='Alpha', slug='zet')
+        Article.objects.create(title="Alpha", body="Zet", slug="alpha")
+        Article.objects.create(title="Zet", body="Alpha", slug="zet")
 
     def test_canonical_slug(self):
         """
         Test that no redirect occurs when slug is canonical
         """
-        resp = self.client.get('/article-canonical-custom-kwargs/1-alpha/')
+        resp = self.client.get("/article-canonical-custom-kwargs/1-alpha/")
         self.assertEqual(resp.status_code, 200)
-        resp = self.client.get('/article-canonical-custom-kwargs/2-zet/')
+        resp = self.client.get("/article-canonical-custom-kwargs/2-zet/")
         self.assertEqual(resp.status_code, 200)
 
     def test_non_canonical_slug(self):
         """
         Test that a redirect occurs when the slug is non-canonical.
         """
-        resp = self.client.get('/article-canonical-custom-kwargs/1-bad-slug/')
+        resp = self.client.get("/article-canonical-custom-kwargs/1-bad-slug/")
         self.assertEqual(resp.status_code, 301)
-        resp = self.client.get('/article-canonical-custom-kwargs/2-bad-slug/')
+        resp = self.client.get("/article-canonical-custom-kwargs/2-bad-slug/")
         self.assertEqual(resp.status_code, 301)
 
 
 class TestModelCanonicalSlugDetailView(test.TestCase):
     def setUp(self):
         CanonicalArticle.objects.create(
-            title='Alpha', body='Zet', slug='alpha')
-        CanonicalArticle.objects.create(
-            title='Zet', body='Alpha', slug='zet')
+            title="Alpha", body="Zet", slug="alpha"
+        )
+        CanonicalArticle.objects.create(title="Zet", body="Alpha", slug="zet")
 
     def test_canonical_slug(self):
         """
         Test that no redirect occurs when slug is canonical according to the
         model's canonical slug.
         """
-        resp = self.client.get('/article-canonical-model/1-unauthored-alpha/')
+        resp = self.client.get("/article-canonical-model/1-unauthored-alpha/")
         self.assertEqual(resp.status_code, 200)
-        resp = self.client.get('/article-canonical-model/2-unauthored-zet/')
+        resp = self.client.get("/article-canonical-model/2-unauthored-zet/")
         self.assertEqual(resp.status_code, 200)
 
     def test_non_canonical_slug(self):
         """
         Test that a redirect occurs when the slug is non-canonical.
         """
-        resp = self.client.get('/article-canonical-model/1-bad-slug/')
+        resp = self.client.get("/article-canonical-model/1-bad-slug/")
         self.assertEqual(resp.status_code, 301)
-        resp = self.client.get('/article-canonical-model/2-bad-slug/')
+        resp = self.client.get("/article-canonical-model/2-bad-slug/")
         self.assertEqual(resp.status_code, 301)
 
 
 # CookieStorage is used because it doesn't require middleware to be installed
 @override_settings(
-    MESSAGE_STORAGE='django.contrib.messages.storage.cookie.CookieStorage')
+    MESSAGE_STORAGE="django.contrib.messages.storage.cookie.CookieStorage"
+)
 class MessageMixinTests(test.TestCase):
     def setUp(self):
         self.rf = test.RequestFactory()
         self.middleware = MessageMiddleware()
 
     def get_request(self, *args, **kwargs):
-        request = self.rf.get('/')
+        request = self.rf.get("/")
         self.middleware.process_request(request)
         return request
 
@@ -536,22 +582,23 @@ class MessageMixinTests(test.TestCase):
     def test_add_messages(self):
         class TestView(MessageMixin, View):
             def get(self, request):
-                self.messages.add_message(messages.SUCCESS, 'test')
-                return HttpResponse('OK')
+                self.messages.add_message(messages.SUCCESS, "test")
+                return HttpResponse("OK")
 
         request, response = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
         self.assertEqual(len(msg), 1)
-        self.assertEqual(msg[0].message, 'test')
+        self.assertEqual(msg[0].message, "test")
         self.assertEqual(msg[0].level, messages.SUCCESS)
 
     def test_get_messages(self):
         class TestView(MessageMixin, View):
             def get(self, request):
-                self.messages.add_message(messages.SUCCESS, 'success')
-                self.messages.add_message(messages.WARNING, 'warning')
-                content = ','.join(
-                    m.message for m in self.messages.get_messages())
+                self.messages.add_message(messages.SUCCESS, "success")
+                self.messages.add_message(messages.WARNING, "warning")
+                content = ",".join(
+                    m.message for m in self.messages.get_messages()
+                )
                 return HttpResponse(content)
 
         _, response = self.get_request_response(TestView.as_view())
@@ -569,75 +616,75 @@ class MessageMixinTests(test.TestCase):
         class TestView(MessageMixin, View):
             def get(self, request):
                 self.messages.set_level(messages.WARNING)
-                self.messages.add_message(messages.SUCCESS, 'success')
-                self.messages.add_message(messages.WARNING, 'warning')
-                return HttpResponse('OK')
+                self.messages.add_message(messages.SUCCESS, "success")
+                self.messages.add_message(messages.WARNING, "warning")
+                return HttpResponse("OK")
 
         request, _ = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
-        self.assertEqual(msg, [Message(messages.WARNING, 'warning')])
+        self.assertEqual(msg, [Message(messages.WARNING, "warning")])
 
     @override_settings(MESSAGE_LEVEL=messages.DEBUG)
     def test_debug(self):
         class TestView(MessageMixin, View):
             def get(self, request):
                 self.messages.debug("test")
-                return HttpResponse('OK')
+                return HttpResponse("OK")
 
         request, _ = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
         self.assertEqual(len(msg), 1)
-        self.assertEqual(msg[0], Message(messages.DEBUG, 'test'))
+        self.assertEqual(msg[0], Message(messages.DEBUG, "test"))
 
     def test_info(self):
         class TestView(MessageMixin, View):
             def get(self, request):
                 self.messages.info("test")
-                return HttpResponse('OK')
+                return HttpResponse("OK")
 
         request, _ = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
         self.assertEqual(len(msg), 1)
-        self.assertEqual(msg[0], Message(messages.INFO, 'test'))
+        self.assertEqual(msg[0], Message(messages.INFO, "test"))
 
     def test_success(self):
         class TestView(MessageMixin, View):
             def get(self, request):
                 self.messages.success("test")
-                return HttpResponse('OK')
+                return HttpResponse("OK")
 
         request, _ = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
         self.assertEqual(len(msg), 1)
-        self.assertEqual(msg[0], Message(messages.SUCCESS, 'test'))
+        self.assertEqual(msg[0], Message(messages.SUCCESS, "test"))
 
     def test_warning(self):
         class TestView(MessageMixin, View):
             def get(self, request):
                 self.messages.warning("test")
-                return HttpResponse('OK')
+                return HttpResponse("OK")
 
         request, _ = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
         self.assertEqual(len(msg), 1)
-        self.assertEqual(msg[0], Message(messages.WARNING, 'test'))
+        self.assertEqual(msg[0], Message(messages.WARNING, "test"))
 
     def test_error(self):
         class TestView(MessageMixin, View):
             def get(self, request):
                 self.messages.error("test")
-                return HttpResponse('OK')
+                return HttpResponse("OK")
 
         request, _ = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
         self.assertEqual(len(msg), 1)
-        self.assertEqual(msg[0], Message(messages.ERROR, 'test'))
+        self.assertEqual(msg[0], Message(messages.ERROR, "test"))
 
     def test_invalid_attribute(self):
         class TestView(MessageMixin, View):
             def get(self, request):
                 self.messages.invalid()
-                return HttpResponse('OK')
+                return HttpResponse("OK")
 
         with self.assertRaises(AttributeError):
             self.get_request_response(TestView.as_view())
@@ -647,18 +694,19 @@ class MessageMixinTests(test.TestCase):
         Make sure that self.messages is available in dispatch() even before
         calling the parent's implementation.
         """
+
         class TestView(MessageMixin, View):
             def dispatch(self, request):
-                self.messages.add_message(messages.SUCCESS, 'test')
+                self.messages.add_message(messages.SUCCESS, "test")
                 return super(TestView, self).dispatch(request)
 
             def get(self, request):
-                return HttpResponse('OK')
+                return HttpResponse("OK")
 
         request, response = self.get_request_response(TestView.as_view())
         msg = list(request._messages)
         self.assertEqual(len(msg), 1)
-        self.assertEqual(msg[0].message, 'test')
+        self.assertEqual(msg[0].message, "test")
         self.assertEqual(msg[0].level, messages.SUCCESS)
 
     def test_API(self):
@@ -668,21 +716,16 @@ class MessageMixinTests(test.TestCase):
         # This test is designed to break when django.contrib.messages.api
         # changes (items being added or removed).
         excluded_API = set()
-        excluded_API.add('MessageFailure')
+        excluded_API.add("MessageFailure")
 
 
 class TestFormMessageMixins(test.TestCase):
     def setUp(self):
-        self.good_data = {
-            'title': 'Good',
-            'body': 'Body'
-        }
-        self.bad_data = {
-            'body': 'Missing title'
-        }
+        self.good_data = {"title": "Good", "body": "Body"}
+        self.bad_data = {"body": "Missing title"}
 
     def test_valid_message(self):
-        url = '/form_messages/'
+        url = "/form_messages/"
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
@@ -691,7 +734,7 @@ class TestFormMessageMixins(test.TestCase):
         self.assertContains(response, FormMessagesView().form_valid_message)
 
     def test_invalid_message(self):
-        url = '/form_messages/'
+        url = "/form_messages/"
         response = self.client.get(url)
         self.assertEqual(response.status_code, 200)
 
@@ -706,14 +749,14 @@ class TestFormMessageMixins(test.TestCase):
 
     def test_form_valid_message_not_str(self):
         mixin = FormValidMessageMixin()
-        mixin.form_valid_message = ['bad']
+        mixin.form_valid_message = ["bad"]
         with self.assertRaises(ImproperlyConfigured):
             mixin.get_form_valid_message()
 
     def test_form_valid_returns_message(self):
         mixin = FormValidMessageMixin()
-        mixin.form_valid_message = 'Good øø'
-        self.assertEqual(force_string('Good øø'), mixin.get_form_valid_message())
+        mixin.form_valid_message = "Good øø"
+        self.assertEqual(force_str("Good øø"), mixin.get_form_valid_message())
 
     def test_form_invalid_message_not_set(self):
         mixin = FormInvalidMessageMixin()
@@ -722,14 +765,14 @@ class TestFormMessageMixins(test.TestCase):
 
     def test_form_invalid_message_not_str(self):
         mixin = FormInvalidMessageMixin()
-        mixin.form_invalid_message = ['bad']
+        mixin.form_invalid_message = ["bad"]
         with self.assertRaises(ImproperlyConfigured):
             mixin.get_form_invalid_message()
 
     def test_form_invalid_returns_message(self):
         mixin = FormInvalidMessageMixin()
-        mixin.form_invalid_message = 'Bad øø'
-        self.assertEqual(force_string('Bad øø'), mixin.get_form_invalid_message())
+        mixin.form_invalid_message = "Bad øø"
+        self.assertEqual(force_str("Bad øø"), mixin.get_form_invalid_message())
 
 
 class TestAllVerbsMixin(test.TestCase):
@@ -763,21 +806,20 @@ class TestAllVerbsMixin(test.TestCase):
 
     def test_no_all_handler(self):
         with self.assertRaises(ImproperlyConfigured):
-            self.client.get('/all_verbs_no_handler/')
+            self.client.get("/all_verbs_no_handler/")
 
 
 class TestHeaderMixin(test.TestCase):
-
     def test_attribute(self):
-        response = self.client.get('/headers/attribute/')
-        self.assertEqual(response['X-DJANGO-BRACES-1'], '1')
-        self.assertEqual(response['X-DJANGO-BRACES-2'], '2')
+        response = self.client.get("/headers/attribute/")
+        self.assertEqual(response["X-DJANGO-BRACES-1"], "1")
+        self.assertEqual(response["X-DJANGO-BRACES-2"], "2")
 
     def test_method(self):
-        response = self.client.get('/headers/method/')
-        self.assertEqual(response['X-DJANGO-BRACES-1'], '1')
-        self.assertEqual(response['X-DJANGO-BRACES-2'], '2')
+        response = self.client.get("/headers/method/")
+        self.assertEqual(response["X-DJANGO-BRACES-1"], "1")
+        self.assertEqual(response["X-DJANGO-BRACES-2"], "2")
 
     def test_existing(self):
-        response = self.client.get('/headers/existing/')
-        self.assertEqual(response['X-DJANGO-BRACES-EXISTING'], 'value')
+        response = self.client.get("/headers/existing/")
+        self.assertEqual(response["X-DJANGO-BRACES-EXISTING"], "value")
