@@ -1,15 +1,17 @@
-from __future__ import absolute_import
-
 import codecs
 
 from django.contrib.auth.models import User
 from django.http import HttpResponse
-try:
-    from django.utils.translation import gettext_lazy as _
-except ImportError:
-    from django.utils.translation import ugettext_lazy as _
-from django.views.generic import (View, UpdateView, FormView, TemplateView,
-                                  ListView, DetailView, CreateView)
+from django.utils.translation import gettext_lazy as _
+from django.views.generic import (
+    View,
+    UpdateView,
+    FormView,
+    TemplateView,
+    ListView,
+    DetailView,
+    CreateView,
+)
 
 from braces import views
 
@@ -22,6 +24,7 @@ class OkView(View):
     """
     A view which simply returns "OK" for every request.
     """
+
     def get(self, request):
         return HttpResponse("OK")
 
@@ -47,7 +50,8 @@ class AnonymousRequiredView(views.AnonymousRequiredMixin, OkView):
     unauthenticated users and redirect authenticated users to the
     authenticated_redirect_url set on the view.
     """
-    authenticated_redirect_url = '/authenticated_view/'
+
+    authenticated_redirect_url = "/authenticated_view/"
 
 
 class AuthenticatedView(views.LoginRequiredMixin, OkView):
@@ -61,6 +65,7 @@ class AjaxResponseView(views.AjaxResponseMixin, OkView):
     """
     A view for testing AjaxResponseMixin.
     """
+
     def get_ajax(self, request):
         return HttpResponse("AJAX_OK")
 
@@ -78,8 +83,9 @@ class SimpleJsonView(views.JSONResponseMixin, View):
     """
     A view for testing JSONResponseMixin's render_json_response() method.
     """
+
     def get(self, request):
-        object = {'username': request.user.username}
+        object = {"username": request.user.username}
         return self.render_json_response(object)
 
 
@@ -88,10 +94,11 @@ class CustomJsonEncoderView(views.JSONResponseMixin, View):
     A view for testing JSONResponseMixin's `json_encoder_class` attribute
     with custom JSONEncoder class.
     """
+
     json_encoder_class = SetJSONEncoder
 
     def get(self, request):
-        object = {'numbers': set([1, 2, 3])}
+        object = {"numbers": set([1, 2, 3])}
         return self.render_json_response(object)
 
 
@@ -100,8 +107,9 @@ class SimpleJsonBadRequestView(views.JSONResponseMixin, View):
     A view for testing JSONResponseMixin's render_json_response() method with
     400 HTTP status code.
     """
+
     def get(self, request):
-        object = {'username': request.user.username}
+        object = {"username": request.user.username}
         return self.render_json_response(object, status=400)
 
 
@@ -110,16 +118,17 @@ class ArticleListJsonView(views.JSONResponseMixin, View):
     A view for testing JSONResponseMixin's render_json_object_response()
     method.
     """
+
     def get(self, request):
         queryset = Article.objects.all()
-        return self.render_json_object_response(
-            queryset, fields=('title',))
+        return self.render_json_object_response(queryset, fields=("title",))
 
 
 class JsonRequestResponseView(views.JsonRequestResponseMixin, View):
     """
     A view for testing JsonRequestResponseMixin's json conversion
     """
+
     def post(self, request):
         return self.render_json_response(self.request_json)
 
@@ -129,6 +138,7 @@ class JsonBadRequestView(views.JsonRequestResponseMixin, View):
     A view for testing JsonRequestResponseMixin's require_json
     and render_bad_request_response methods
     """
+
     require_json = True
 
     def post(self, request, *args, **kwargs):
@@ -140,10 +150,10 @@ class JsonCustomBadRequestView(views.JsonRequestResponseMixin, View):
     A view for testing JsonRequestResponseMixin's
     render_bad_request_response method with a custom error message
     """
+
     def post(self, request, *args, **kwargs):
         if not self.request_json:
-            return self.render_bad_request_response(
-                {'error': 'you messed up'})
+            return self.render_bad_request_response({"error": "you messed up"})
         return self.render_json_response(self.request_json)
 
 
@@ -151,32 +161,38 @@ class CreateArticleView(CreateView):
     """
     View for testing CreateAndRedirectEditToView.
     """
-    fields = ['author', 'title', 'body', 'slug']
+
+    fields = ["author", "title", "body", "slug"]
     model = Article
-    template_name = 'form.html'
+    template_name = "form.html"
 
 
 class EditArticleView(UpdateView):
     """
     View for testing CreateAndRedirectEditToView.
     """
+
     model = Article
-    template_name = 'form.html'
+    template_name = "form.html"
 
 
-class CreateArticleAndRedirectToListView(views.SuccessURLRedirectListMixin,
-                                         CreateArticleView):
+class CreateArticleAndRedirectToListView(
+    views.SuccessURLRedirectListMixin, CreateArticleView
+):
     """
     View for testing SuccessURLRedirectListMixin
     """
-    success_list_url = 'article_list'
+
+    success_list_url = "article_list"
 
 
-class CreateArticleAndRedirectToListViewBad(views.SuccessURLRedirectListMixin,
-                                            CreateArticleView):
+class CreateArticleAndRedirectToListViewBad(
+    views.SuccessURLRedirectListMixin, CreateArticleView
+):
     """
     View for testing SuccessURLRedirectListMixin
     """
+
     success_list_url = None
 
 
@@ -186,18 +202,21 @@ class ArticleListView(views.SelectRelatedMixin, ListView):
 
     Also used to test SelectRelatedMixin.
     """
+
     model = Article
-    template_name = 'blank.html'
-    select_related = ('author',)
+    template_name = "blank.html"
+    select_related = ("author",)
 
 
 class ArticleListViewWithCustomQueryset(views.SelectRelatedMixin, ListView):
     """
     Another list view for articles, required to test SelectRelatedMixin.
     """
-    queryset = Article.objects.select_related('author').prefetch_related(
-        'article_set')
-    template_name = 'blank.html'
+
+    queryset = Article.objects.select_related("author").prefetch_related(
+        "article_set"
+    )
+    template_name = "blank.html"
     select_related = ()
 
 
@@ -205,8 +224,9 @@ class FormWithUserKwargView(views.UserFormKwargsMixin, FormView):
     """
     View for testing UserFormKwargsMixin.
     """
+
     form_class = FormWithUserKwarg
-    template_name = 'form.html'
+    template_name = "form.html"
 
     def form_valid(self, form):
         return HttpResponse("username: %s" % form.user.username)
@@ -216,7 +236,8 @@ class HeadlineView(views.SetHeadlineMixin, TemplateView):
     """
     View for testing SetHeadlineMixin.
     """
-    template_name = 'blank.html'
+
+    template_name = "blank.html"
     headline = "Test headline"
 
 
@@ -224,38 +245,43 @@ class LazyHeadlineView(views.SetHeadlineMixin, TemplateView):
     """
     View for testing SetHeadlineMixin.
     """
-    template_name = 'blank.html'
+
+    template_name = "blank.html"
     headline = _("Test Headline")
 
 
 class ContextView(views.StaticContextMixin, TemplateView):
-    """ View for testing StaticContextMixin. """
-    template_name = 'blank.html'
-    static_context = {'test': True}
+    """View for testing StaticContextMixin."""
+
+    template_name = "blank.html"
+    static_context = {"test": True}
 
 
 class DynamicHeadlineView(views.SetHeadlineMixin, TemplateView):
     """
     View for testing SetHeadlineMixin's get_headline() method.
     """
-    template_name = 'blank.html'
+
+    template_name = "blank.html"
 
     def get_headline(self):
-        return self.kwargs['s']
+        return self.kwargs["s"]
 
 
 class PermissionRequiredView(views.PermissionRequiredMixin, OkView):
     """
     View for testing PermissionRequiredMixin.
     """
-    permission_required = 'auth.add_user'
+
+    permission_required = "auth.add_user"
 
 
-class MultiplePermissionsRequiredView(views.MultiplePermissionsRequiredMixin,
-                                      OkView):
+class MultiplePermissionsRequiredView(
+    views.MultiplePermissionsRequiredMixin, OkView
+):
     permissions = {
-        'all': ['tests.add_article', 'tests.change_article'],
-        'any': ['auth.add_user', 'auth.change_user'],
+        "all": ["tests.add_article", "tests.change_article"],
+        "any": ["auth.add_user", "auth.change_user"],
     }
 
 
@@ -273,68 +299,79 @@ class CsrfExemptView(views.CsrfExemptMixin, OkView):
 
 class AuthorDetailView(views.PrefetchRelatedMixin, ListView):
     model = User
-    prefetch_related = ['article_set']
-    template_name = 'blank.html'
+    prefetch_related = ["article_set"]
+    template_name = "blank.html"
 
 
 class OrderableListView(views.OrderableListMixin, ListView):
     model = Article
-    orderable_columns = ('id', 'title', )
-    orderable_columns_default = 'id'
+    orderable_columns = (
+        "id",
+        "title",
+    )
+    orderable_columns_default = "id"
 
 
 class CanonicalSlugDetailView(views.CanonicalSlugDetailMixin, DetailView):
     model = Article
-    template_name = 'blank.html'
+    template_name = "blank.html"
 
 
-class OverriddenCanonicalSlugDetailView(views.CanonicalSlugDetailMixin,
-                                        DetailView):
+class OverriddenCanonicalSlugDetailView(
+    views.CanonicalSlugDetailMixin, DetailView
+):
     model = Article
-    template_name = 'blank.html'
+    template_name = "blank.html"
 
     def get_canonical_slug(self):
-        return codecs.encode(self.get_object().slug, 'rot_13')
+        return codecs.encode(self.get_object().slug, "rot_13")
 
 
-class CanonicalSlugDetailCustomUrlKwargsView(views.CanonicalSlugDetailMixin,
-                                             DetailView):
+class CanonicalSlugDetailCustomUrlKwargsView(
+    views.CanonicalSlugDetailMixin, DetailView
+):
     model = Article
-    template_name = 'blank.html'
-    pk_url_kwarg = 'my_pk'
-    slug_url_kwarg = 'my_slug'
+    template_name = "blank.html"
+    pk_url_kwarg = "my_pk"
+    slug_url_kwarg = "my_slug"
 
 
-class ModelCanonicalSlugDetailView(views.CanonicalSlugDetailMixin,
-                                   DetailView):
+class ModelCanonicalSlugDetailView(views.CanonicalSlugDetailMixin, DetailView):
     model = CanonicalArticle
-    template_name = 'blank.html'
+    template_name = "blank.html"
 
 
 class FormMessagesView(views.FormMessagesMixin, CreateView):
     form_class = ArticleForm
-    form_invalid_message = _('Invalid')
-    form_valid_message = _('Valid')
+    form_invalid_message = _("Invalid")
+    form_valid_message = _("Valid")
     model = Article
-    success_url = '/form_messages/'
-    template_name = 'form.html'
+    success_url = "/form_messages/"
+    template_name = "form.html"
 
 
 class GroupRequiredView(views.GroupRequiredMixin, OkView):
-    group_required = 'test_group'
+    group_required = "test_group"
 
 
 class UserPassesTestView(views.UserPassesTestMixin, OkView):
     def test_func(self, user):
-        return user.is_staff and not user.is_superuser \
-            and user.email.endswith('@mydomain.com')
+        return (
+            user.is_staff
+            and not user.is_superuser
+            and user.email.endswith("@mydomain.com")
+        )
 
 
-class UserPassesTestLoginRequiredView(views.LoginRequiredMixin,
-                                      views.UserPassesTestMixin, OkView):
+class UserPassesTestLoginRequiredView(
+    views.LoginRequiredMixin, views.UserPassesTestMixin, OkView
+):
     def test_func(self, user):
-        return user.is_staff and not user.is_superuser \
-            and user.email.endswith('@mydomain.com')
+        return (
+            user.is_staff
+            and not user.is_superuser
+            and user.email.endswith("@mydomain.com")
+        )
 
 
 class UserPassesTestNotImplementedView(views.UserPassesTestMixin, OkView):
@@ -343,7 +380,7 @@ class UserPassesTestNotImplementedView(views.UserPassesTestMixin, OkView):
 
 class AllVerbsView(views.AllVerbsMixin, View):
     def all(self, request, *args, **kwargs):
-        return HttpResponse('All verbs return this!')
+        return HttpResponse("All verbs return this!")
 
 
 class SSLRequiredView(views.SSLRequiredMixin, OkView):
@@ -358,29 +395,25 @@ class RecentLoginRequiredView(views.RecentLoginRequiredMixin, OkView):
 
 class AttributeHeaderView(views.HeaderMixin, OkView):
     headers = {
-        'X-DJANGO-BRACES-1': 1,
-        'X-DJANGO-BRACES-2': 2,
+        "X-DJANGO-BRACES-1": 1,
+        "X-DJANGO-BRACES-2": 2,
     }
 
 
 class MethodHeaderView(views.HeaderMixin, OkView):
-
     def get_headers(self, request):
         return {
-            'X-DJANGO-BRACES-1': 1,
-            'X-DJANGO-BRACES-2': 2,
+            "X-DJANGO-BRACES-1": 1,
+            "X-DJANGO-BRACES-2": 2,
         }
 
 
 class AuxiliaryHeaderView(View):
-
     def dispatch(self, request, *args, **kwargs):
-        response = HttpResponse('OK with headers')
-        response['X-DJANGO-BRACES-EXISTING'] = 'value'
+        response = HttpResponse("OK with headers")
+        response["X-DJANGO-BRACES-EXISTING"] = "value"
         return response
 
 
 class ExistingHeaderView(views.HeaderMixin, AuxiliaryHeaderView):
-    headers = {
-        'X-DJANGO-BRACES-EXISTING': 'other value'
-    }
+    headers = {"X-DJANGO-BRACES-EXISTING": "other value"}
